@@ -398,7 +398,10 @@ class ezfuc(object):
         for line in tqdm(resList, ascii=True, desc=excel_name):
             r = 00
             for i in line:
-                sheet.write(l, r, i)  # 一个一个将单元格数据写入
+                try:
+                    sheet.write(l, r, i.strip())  # 一个一个将单元格数据写入
+                except AttributeError:
+                    sheet.write(l, r, i)
                 r = r + 1
             l = l + 1
         workbook.close()
@@ -521,7 +524,7 @@ class EmailSend(object):
 @ezfuc.retry(2)
 def getIP():
     try:
-        res = requests.get("http://192.168.18.8:39111/123", timeout=3).json()
+        res = requests.get("http://101.37.70.55:39113/123", timeout=3).json()
     except:
         return None
 
@@ -536,7 +539,7 @@ def getIP():
 import base64
 
 # 代理隧道验证信息
-proxyUser = "2120061500000940938"
+proxyUser = "2120081800107971646"
 proxyPass = "fBGcLkyNK6He1FBn"
 
 # for Python3
